@@ -29,13 +29,13 @@ class TestPoliticianNameCleaver(unittest.TestCase):
         self.assertEqual('Albert Gore', str(PoliticianNameCleaver('Gore, Albert').parse()))
 
     def test_pile_it_on(self):
-        self.assertEqual('Milton Elmer McCullough Jr', str(PoliticianNameCleaver('Milton Elmer "Mac" McCullough, Jr (3)').parse()))
+        self.assertEqual('Milton Elmer McCullough, Jr.', str(PoliticianNameCleaver('Milton Elmer "Mac" McCullough, Jr (3)').parse()))
 
     def test_pile_it_on_two(self):
-        self.assertEqual('William Steve Southerland II', str(PoliticianNameCleaver('William Steve Southerland  II (R)').parse()))
+        self.assertEqual('William Steve Southerland, II', str(PoliticianNameCleaver('William Steve Southerland  II (R)').parse()))
 
     def test_pile_it_on_three(self):
-        self.assertEqual('Edward Thomas O\'Donnell Jr', str(PoliticianNameCleaver('Edward Thomas O\'Donnell, Jr (D)').parse()))
+        self.assertEqual('Edward Thomas O\'Donnell, Jr.', str(PoliticianNameCleaver('Edward Thomas O\'Donnell, Jr (D)').parse()))
 
     def test_standardize_running_mate_names(self):
         self.assertEqual('John Kasich & Mary Taylor', str(PoliticianNameCleaver('Kasich, John & Taylor, Mary').parse()))
@@ -44,17 +44,17 @@ class TestPoliticianNameCleaver(unittest.TestCase):
         self.assertEqual('Mitt Romney & Paul D. Ryan', str(PoliticianNameCleaver('ROMNEY, MITT / RYAN, PAUL D.').parse()))
 
     def test_we_dont_need_no_steeenking_nicknames(self):
-        self.assertEqual('Robert M McDonnell', str(PoliticianNameCleaver('McDonnell, Robert M (Bob)').parse()))
-        self.assertEqual('John J Duncan Jr', str(PoliticianNameCleaver('John J (Jimmy) Duncan Jr (R)').parse()))
+        self.assertEqual('Robert M. McDonnell', str(PoliticianNameCleaver('McDonnell, Robert M (Bob)').parse()))
+        self.assertEqual('John J. Duncan, Jr.', str(PoliticianNameCleaver('John J (Jimmy) Duncan Jr (R)').parse()))
         self.assertEqual('Christopher Bond', str(PoliticianNameCleaver('Christopher "Kit" Bond').parse()))
 
     def test_capitalize_roman_numeral_suffixes(self):
-        self.assertEqual('Ken Cuccinelli II', str(PoliticianNameCleaver('KEN CUCCINELLI II').parse()))
-        self.assertEqual('Ken Cuccinelli II', str(PoliticianNameCleaver('CUCCINELLI II, KEN').parse()))
-        self.assertEqual('Ken T Cuccinelli II', str(PoliticianNameCleaver('CUCCINELLI II, KEN T').parse()))
-        self.assertEqual('Ken T Cuccinelli II', str(PoliticianNameCleaver('CUCCINELLI, KEN T II').parse()))
-        self.assertEqual('Ken Cuccinelli IV', str(PoliticianNameCleaver('CUCCINELLI IV, KEN').parse()))
-        self.assertEqual('Ken Cuccinelli IX', str(PoliticianNameCleaver('CUCCINELLI IX, KEN').parse()))
+        self.assertEqual('Ken Cuccinelli, II', str(PoliticianNameCleaver('KEN CUCCINELLI II').parse()))
+        self.assertEqual('Ken Cuccinelli, II', str(PoliticianNameCleaver('CUCCINELLI II, KEN').parse()))
+        self.assertEqual('Ken T. Cuccinelli, II', str(PoliticianNameCleaver('CUCCINELLI II, KEN T').parse()))
+        self.assertEqual('Ken T. Cuccinelli, II', str(PoliticianNameCleaver('CUCCINELLI, KEN T II').parse()))
+        self.assertEqual('Ken Cuccinelli, IV', str(PoliticianNameCleaver('CUCCINELLI IV, KEN').parse()))
+        self.assertEqual('Ken Cuccinelli, IX', str(PoliticianNameCleaver('CUCCINELLI IX, KEN').parse()))
 
     def test_name_with_two_part_last_name(self):
         self.assertEqual('La Mere', PoliticianNameCleaver('Albert J La Mere').parse().last)
@@ -103,6 +103,12 @@ class TestPoliticianNameCleaver(unittest.TestCase):
     def test_van_is_valid_first_name(self):
         self.assertEqual(['Van', 'Morrison'], PoliticianNameCleaver('Van Morrison').parse().primary_name_parts())
 
+    def test_alternate_running_mates_format(self):
+        self.assertEqual('Obama/Biden 2012', str(PoliticianNameCleaver('2012, Obama/Biden').parse()))
+
+    def test_alternate_punctuation(self):
+        self.assertEqual('Charles W. Boustany, Jr.', str(PoliticianNameCleaver('Charles W. Boustany Jr.').parse()))
+
 
 class TestOrganizationNameCleaver(unittest.TestCase):
 
@@ -169,34 +175,34 @@ class TestIndividualNameCleaver(unittest.TestCase):
         self.assertEqual('Lee', self.cleave_to_str('LEE'))
 
     def test_all_kinds_of_crazy(self):
-        self.assertEqual('Stanford Z Rothschild', self.cleave_to_str('ROTHSCHILD 212, STANFORD Z MR'))
+        self.assertEqual('Stanford Z. Rothschild', self.cleave_to_str('ROTHSCHILD 212, STANFORD Z MR'))
 
     def test_jr_and_the_like_end_up_at_the_end(self):
-        self.assertEqual('Frederick A "Tripp" Baird III', self.cleave_to_str('Baird, Frederick A "Tripp" III'))
+        self.assertEqual('Frederick A. "Tripp" Baird, III', self.cleave_to_str('Baird, Frederick A "Tripp" III'))
 
     def test_nicknames_suffixes_and_honorifics(self):
-        self.assertEqual('Frederick A "Tripp" Baird III', self.cleave_to_str('Baird, Frederick A "Tripp" III Mr'))
-        self.assertEqual('Frederick A "Tripp" Baird III', self.cleave_to_str('Baird, Mr Frederick A "Tripp" III'))
+        self.assertEqual('Frederick A. "Tripp" Baird, III', self.cleave_to_str('Baird, Frederick A "Tripp" III Mr'))
+        self.assertEqual('Frederick A. "Tripp" Baird, III', self.cleave_to_str('Baird, Mr Frederick A "Tripp" III'))
 
     def test_throw_out_mr(self):
-        self.assertEqual('T Boone Pickens', self.cleave_to_str('Mr T Boone Pickens'))
-        self.assertEqual('T Boone Pickens', self.cleave_to_str('Mr. T Boone Pickens'))
-        self.assertEqual('T Boone Pickens', self.cleave_to_str('Pickens, T Boone Mr'))
-        self.assertEqual('John L Nau', self.cleave_to_str(' MR JOHN L NAU,'))
+        self.assertEqual('T. Boone Pickens', self.cleave_to_str('Mr T Boone Pickens'))
+        self.assertEqual('T. Boone Pickens', self.cleave_to_str('Mr. T Boone Pickens'))
+        self.assertEqual('T. Boone Pickens', self.cleave_to_str('Pickens, T Boone Mr'))
+        self.assertEqual('John L. Nau', self.cleave_to_str(' MR JOHN L NAU,'))
 
     def test_keep_the_mrs(self):
-        self.assertEqual('Mrs. T Boone Pickens', self.cleave_to_str('Mrs T Boone Pickens'))
-        self.assertEqual('Mrs. T Boone Pickens', self.cleave_to_str('Mrs. T Boone Pickens'))
-        self.assertEqual('Mrs. Stanford Z Rothschild', self.cleave_to_str('ROTHSCHILD 212, STANFORD Z MRS'))
+        self.assertEqual('Mrs. T. Boone Pickens', self.cleave_to_str('Mrs T Boone Pickens'))
+        self.assertEqual('Mrs. T. Boone Pickens', self.cleave_to_str('Mrs. T Boone Pickens'))
+        self.assertEqual('Mrs. Stanford Z. Rothschild', self.cleave_to_str('ROTHSCHILD 212, STANFORD Z MRS'))
 
     def test_mrs_walton(self):
         self.assertEqual('Mrs. Jim Walton', self.cleave_to_str('WALTON, JIM MRS'))
 
     def test_capitalize_roman_numeral_suffixes(self):
-        self.assertEqual('Ken Cuccinelli II', self.cleave_to_str('KEN CUCCINELLI II'))
-        self.assertEqual('Ken Cuccinelli II', self.cleave_to_str('CUCCINELLI II, KEN'))
-        self.assertEqual('Ken Cuccinelli IV', self.cleave_to_str('CUCCINELLI IV, KEN'))
-        self.assertEqual('Ken Cuccinelli IX', self.cleave_to_str('CUCCINELLI IX, KEN'))
+        self.assertEqual('Ken Cuccinelli, II', self.cleave_to_str('KEN CUCCINELLI II'))
+        self.assertEqual('Ken Cuccinelli, II', self.cleave_to_str('CUCCINELLI II, KEN'))
+        self.assertEqual('Ken Cuccinelli, IV', self.cleave_to_str('CUCCINELLI IV, KEN'))
+        self.assertEqual('Ken Cuccinelli, IX', self.cleave_to_str('CUCCINELLI IX, KEN'))
 
     def test_capitalize_scottish_last_names(self):
         self.assertEqual('Ronald McDonald', self.cleave_to_str('RONALD MCDONALD'))
@@ -212,12 +218,12 @@ class TestIndividualNameCleaver(unittest.TestCase):
         self.assertEqual('Drew Maloney', self.cleave_to_str('Maloney, Drew'))
 
     def test_unfazed_by_weird_cop_cont_parenthetical_phrases(self):
-        self.assertEqual('Jacqueline A Schmitz', self.cleave_to_str('SCHMITZ (COP CONT ), JACQUELINE A'))
+        self.assertEqual('Jacqueline A. Schmitz', self.cleave_to_str('SCHMITZ (COP CONT ), JACQUELINE A'))
         self.assertEqual('Hannah Mellman', self.cleave_to_str('MELLMAN (CONT\'D), HANNAH (CONT\'D)'))
         self.assertEqual('Tod Preston', self.cleave_to_str('PRESTON (C O P CONT\'D ), TOD'))
 
     def test_mr_and_mrs(self):
-        self.assertEqual('Kenneth L Lay', self.cleave_to_str('LAY, KENNETH L MR & MRS'))
+        self.assertEqual('Kenneth L. Lay', self.cleave_to_str('LAY, KENNETH L MR & MRS'))
 
     def test_primary_name_parts(self):
         self.assertEqual(['Robert', 'Geoff', 'Smith'], self.cleaver('Smith, Robert Geoff').parse().primary_name_parts(include_middle=True))
@@ -228,9 +234,8 @@ class TestIndividualNameCleaver(unittest.TestCase):
 
     def test_degree_gets_thrown_out(self):
         self.assertEqual('C. Richard Bonebrake', self.cleave_to_str('C. RICHARD BONEBRAKE, M.D.'))
-        # TODO: the placement of the period is an error, but is non-critical for now
-        self.assertEqual('John W Noble. Jr', self.cleave_to_str('NOBLE JR., JOHN W. MD'))
-        self.assertEqual('John W Noble. Jr', self.cleave_to_str('NOBLE JR., JOHN W. PHD MD'))
+        self.assertEqual('John W. Noble, Jr.', self.cleave_to_str('NOBLE JR., JOHN W. MD'))
+        self.assertEqual('John W. Noble, Jr.', self.cleave_to_str('NOBLE JR., JOHN W. PHD MD'))
         self.assertEqual('Barney Dinosaur', self.cleave_to_str('DINOSAUR, BARNEY J.D.'))
 
     def test_two_part_names_skip_suffix_check(self):
